@@ -21,11 +21,16 @@ BARIS_explain <- function(datasetId) {
 
   checkmate::assert_character(datasetId)
 
-
   basic_url <- "https://www.data.gouv.fr/api/1/datasets/"
 
   final_url <- paste("https://www.data.gouv.fr/api/1/datasets/", datasetId, "/", sep = "")
 
+  response_status <- is_response_successfull(final_url)
+
+  if (!response_status) {
+    return(NULL)
+  }
+
   # set memoise cache fct
   mem_fromJSON <- BARIS_set_fromJSON()
 
@@ -33,10 +38,6 @@ BARIS_explain <- function(datasetId) {
 
   Encoding(df_explain$description) <- "UTF-8"
 
-  df_explain$description <- df_explain$description %>%
-    str_replace_all(c("\n" = " ","\r" = " ", "&#x27;" = "'")) %>%
-    str_trim()
-
 
   return(df_explain$description)
 }
